=== modified file 'NEWS'
--- NEWS	2006-12-07 16:26:50 +0000
+++ NEWS	2006-12-07 17:15:28 +0000
@@ -29,6 +29,15 @@
       automatic push location of ``sftp://host/srv/project/mybranch``.
       (James Henstridge)
 
+    * Added ``bzr status --short`` to make status report svn style flags
+      for each file.  For example::
+
+        $ bzr status --short
+        A  foo
+        A  bar
+        D  baz
+        ?  wooley
+      
   INTERNALS:
 
   BUG FIXES:
@@ -58,7 +67,7 @@
       location for general information, outside of a specific command.
       This includes updates for ``bzr help revisionspec`` the first topic
       included. (Goffredo Baroncelli, John Arbash Meinel, #42714)
-      
+
     * WSGI-compatible HTTP smart server.  See ``doc/http_smart_server.txt``.
       (Andrew Bennetts)
 

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-11-28 19:19:15 +0000
+++ bzrlib/builtins.py	2006-12-01 10:26:13 +0000
@@ -128,26 +128,29 @@
     This reports on versioned and unknown files, reporting them
     grouped by state.  Possible states are:
 
-    added
+    added / A
         Versioned in the working copy but not in the previous revision.
 
-    removed
+    removed / D
         Versioned in the previous revision but removed or deleted
         in the working copy.
 
-    renamed
+    renamed / R
         Path of this file changed from the previous revision;
         the text may also have changed.  This includes files whose
         parent directory was renamed.
 
-    modified
+    modified / M
         Text has changed since the previous revision.
 
-    unknown
+    unknown / ?
         Not versioned and not matching an ignore pattern.
 
     To see ignored files use 'bzr ignored'.  For details in the
     changes to file texts, use 'bzr diff'.
+    
+    --short gives a one character status flag for each item, similar
+    to the SVN's status command.
 
     If no arguments are specified, the status of the entire working
     directory is shown.  Otherwise, only the status of the specified
@@ -161,20 +164,21 @@
     # TODO: --no-recurse, --recurse options
     
     takes_args = ['file*']
-    takes_options = ['show-ids', 'revision']
+    takes_options = ['show-ids', 'revision', 'short']
     aliases = ['st', 'stat']
 
     encoding_type = 'replace'
     
     @display_command
-    def run(self, show_ids=False, file_list=None, revision=None):
+    def run(self, show_ids=False, file_list=None, revision=None, short=False):
         from bzrlib.status import show_tree_status
 
         tree, file_list = tree_files(file_list)
             
         show_tree_status(tree, show_ids=show_ids,
                          specific_files=file_list, revision=revision,
-                         to_file=self.outf)
+                         to_file=self.outf,
+                         short=short)
 
 
 class cmd_cat_revision(Command):

=== modified file 'bzrlib/delta.py'
--- bzrlib/delta.py	2006-11-17 06:59:59 +0000
+++ bzrlib/delta.py	2006-12-07 17:15:28 +0000
@@ -91,9 +91,9 @@
         return False
             
 
-    def show(self, to_file, show_ids=False, show_unchanged=False):
+    def show(self, to_file, show_ids=False, show_unchanged=False, short_status=False):
         """output this delta in status-like form to to_file."""
-        def show_list(files):
+        def show_list(files, short_status_letter=''):
             for item in files:
                 path, fid, kind = item[:3]
 
@@ -106,22 +106,31 @@
                     path += '*'
 
                 if show_ids:
-                    print >>to_file, '  %-30s %s' % (path, fid)
+                    print >>to_file, '%s  %-30s %s' % (short_status_letter, path, fid)
                 else:
-                    print >>to_file, ' ', path
+                    print >>to_file, '%s  %s' % (short_status_letter, path)
             
         if self.removed:
-            print >>to_file, 'removed:'
-            show_list(self.removed)
+            if not short_status:
+                print >>to_file, 'removed:'
+                show_list(self.removed)
+            else:
+                show_list(self.removed, 'D')
                 
         if self.added:
-            print >>to_file, 'added:'
-            show_list(self.added)
+            if not short_status:
+                print >>to_file, 'added:'
+                show_list(self.added)
+            else:
+                show_list(self.added, 'A')
 
         extra_modified = []
 
         if self.renamed:
-            print >>to_file, 'renamed:'
+            short_status_letter = 'R'
+            if not short_status:
+                print >>to_file, 'renamed:'
+                short_status_letter = ''
             for (oldpath, newpath, fid, kind,
                  text_modified, meta_modified) in self.renamed:
                 if text_modified or meta_modified:
@@ -130,18 +139,26 @@
                 if meta_modified:
                     newpath += '*'
                 if show_ids:
-                    print >>to_file, '  %s => %s %s' % (oldpath, newpath, fid)
+                    print >>to_file, '%s  %s => %s %s' % (short_status_letter,
+                                                          oldpath, newpath, fid)
                 else:
-                    print >>to_file, '  %s => %s' % (oldpath, newpath)
+                    print >>to_file, '%s  %s => %s' % (short_status_letter,
+                                                       oldpath, newpath)
                     
         if self.modified or extra_modified:
-            print >>to_file, 'modified:'
-            show_list(self.modified)
-            show_list(extra_modified)
+            short_status_letter = 'M'
+            if not short_status:
+                print >>to_file, 'modified:'
+                short_status_letter = ''
+            show_list(self.modified, short_status_letter)
+            show_list(extra_modified, short_status_letter)
             
         if show_unchanged and self.unchanged:
-            print >>to_file, 'unchanged:'
-            show_list(self.unchanged)
+            if not short_status:
+                print >>to_file, 'unchanged:'
+                show_list(self.unchanged)
+            else:
+                show_list(self.unchanged, 'S')
 
 
 @deprecated_function(zero_nine)

=== modified file 'bzrlib/status.py'
--- bzrlib/status.py	2006-10-21 07:59:57 +0000
+++ bzrlib/status.py	2006-12-01 10:31:21 +0000
@@ -76,7 +76,8 @@
                      show_ids=False,
                      to_file=None,
                      show_pending=True,
-                     revision=None):
+                     revision=None,
+                     short=False):
     """Display summary of changes.
 
     By default this compares the working tree to a previous revision. 
@@ -101,6 +102,7 @@
         If not None it must be a RevisionSpec list.
         If one revision show compared it with working tree.
         If two revisions show status between first and second.
+    :param short: If True, gives short SVN-style status lines
     """
     if show_unchanged is not None:
         warn("show_status_trees with show_unchanged has been deprecated "
@@ -137,22 +139,30 @@
                               specific_files=specific_files)
         delta.show(to_file,
                    show_ids=show_ids,
-                   show_unchanged=show_unchanged)
-
-        list_paths('unknown', new.unknowns(), specific_files, to_file)
+                   show_unchanged=show_unchanged,
+                   short_status=short)
+        short_status_letter = '?'
+        if not short:
+            short_status_letter = ''
+        list_paths('unknown', new.unknowns(), specific_files, to_file,
+                   short_status_letter)
         conflict_title = False
         # show the new conflicts only for now. XXX: get them from the delta.
         for conflict in new.conflicts():
-            if conflict_title is False:
+            if not short and conflict_title is False:
                 print >> to_file, "conflicts:"
                 conflict_title = True
-            print >> to_file, "  %s" % conflict
+            if not short:
+                prefix = 'C'
+            else:
+                prefix = ' '
+            print >> to_file, prefix, " %s" % conflict
         if new_is_working_tree and show_pending:
-            show_pending_merges(new, to_file)
+            show_pending_merges(new, to_file, short)
     finally:
         wt.unlock()
 
-def show_pending_merges(new, to_file):
+def show_pending_merges(new, to_file, short=False):
     """Write out a display of pending merges in a working tree."""
     parents = new.get_parent_ids()
     if len(parents) < 2:
@@ -160,7 +170,8 @@
     pending = parents[1:]
     branch = new.branch
     last_revision = parents[0]
-    print >>to_file, 'pending merges:'
+    if not short:
+        print >>to_file, 'pending merges:'
     if last_revision is not None:
         try:
             ignore = set(branch.repository.get_ancestry(last_revision))
@@ -178,7 +189,11 @@
             from bzrlib.osutils import terminal_width
             width = terminal_width()
             m_revision = branch.repository.get_revision(merge)
-            print >> to_file, ' ', line_log(m_revision, width - 3)
+            if short:
+                prefix = 'P'
+            else: 
+                prefix = ' '
+            print >> to_file, prefix, line_log(m_revision, width - 4)
             inner_merges = branch.repository.get_ancestry(merge)
             assert inner_merges[0] is None
             inner_merges.pop(0)
@@ -187,17 +202,25 @@
                 if mmerge in ignore:
                     continue
                 mm_revision = branch.repository.get_revision(mmerge)
-                print >> to_file, '   ', line_log(mm_revision, width - 5)
+                if short:
+                    prefix = 'P. '
+                else:
+                    prefix = '   '
+                print >> to_file, prefix, line_log(mm_revision, width - 5)
                 ignore.add(mmerge)
         except errors.NoSuchRevision:
-            print >> to_file, ' ', merge
+            if short:
+                prefix = 'P'
+            else:
+                prefix = ' '
+            print >> to_file, prefix, merge
         
-def list_paths(header, paths, specific_files, to_file):
+def list_paths(header, paths, specific_files, to_file, short_status_letter=''):
     done_header = False
     for path in paths:
         if specific_files and not is_inside_any(specific_files, path):
             continue
-        if not done_header:
+        if not short_status_letter and not done_header:
             print >>to_file, '%s:' % header
             done_header = True
-        print >>to_file, ' ', path
+        print >>to_file, '%s  %s' % (short_status_letter, path)

=== modified file 'bzrlib/tests/blackbox/test_status.py'
--- bzrlib/tests/blackbox/test_status.py	2006-10-22 04:17:44 +0000
+++ bzrlib/tests/blackbox/test_status.py	2006-11-23 18:56:25 +0000
@@ -41,20 +41,20 @@
 class BranchStatus(TestCaseWithTransport):
     
     def assertStatus(self, output_lines, working_tree,
-        revision=None):
+        revision=None, short=False):
         """Run status in working_tree and look for output.
         
         :param output_lines: The lines to look for.
         :param working_tree: The tree to run status in.
         """
-        output_string = self.status_string(working_tree, revision)
+        output_string = self.status_string(working_tree, revision, short)
         self.assertEqual(output_lines, output_string.splitlines(True))
     
-    def status_string(self, wt, revision=None):
+    def status_string(self, wt, revision=None, short=False):
         # use a real file rather than StringIO because it doesn't handle
         # Unicode very well.
         tof = codecs.getwriter('utf-8')(TemporaryFile())
-        show_tree_status(wt, to_file=tof, revision=revision)
+        show_tree_status(wt, to_file=tof, revision=revision, short=short)
         tof.seek(0)
         return tof.read().decode('utf-8')
 
@@ -75,6 +75,11 @@
                 '  hello.c\n',
             ],
             wt)
+        self.assertStatus([
+                '?  bye.c\n',
+                '?  hello.c\n',
+            ],
+            wt, short=True)
 
         # add a commit to allow showing pending merges.
         wt.commit('create a parent to allow testing merge output')
@@ -88,6 +93,12 @@
                 '  pending@pending-0-0\n',
             ],
             wt)
+        self.assertStatus([
+                '?  bye.c\n',
+                '?  hello.c\n',
+                'P  pending@pending-0-0\n',
+            ],
+            wt, short=True)
 
     def test_branch_status_revisions(self):
         """Tests branch status with revisions"""
@@ -154,16 +165,22 @@
         wt.add('test.c')
         wt.commit('testing')
         
+        self.assertStatus([
+                'unknown:\n',
+                '  bye.c\n',
+                '  dir2\n',
+                '  directory/hello.c\n'
+                ],
+                wt)
+
+        self.assertStatus([
+                '?  bye.c\n',
+                '?  dir2\n',
+                '?  directory/hello.c\n'
+                ],
+                wt, short=True)
+
         tof = StringIO()
-        show_tree_status(wt, to_file=tof)
-        tof.seek(0)
-        self.assertEquals(tof.readlines(),
-                          ['unknown:\n',
-                           '  bye.c\n',
-                           '  dir2\n',
-                           '  directory/hello.c\n'
-                           ])
-
         self.assertRaises(errors.PathsDoNotExist,
                           show_tree_status,
                           wt, specific_files=['bye.c','test.c','absent.c'], 
@@ -177,12 +194,22 @@
                            '  directory/hello.c\n'
                            ])
         tof = StringIO()
+        show_tree_status(wt, specific_files=['directory'], to_file=tof,
+                         short=True)
+        tof.seek(0)
+        self.assertEquals(tof.readlines(), ['?  directory/hello.c\n'])
+
+        tof = StringIO()
         show_tree_status(wt, specific_files=['dir2'], to_file=tof)
         tof.seek(0)
         self.assertEquals(tof.readlines(),
                           ['unknown:\n',
                            '  dir2\n'
                            ])
+        tof = StringIO()
+        show_tree_status(wt, specific_files=['dir2'], to_file=tof, short=True)
+        tof.seek(0)
+        self.assertEquals(tof.readlines(), ['?  dir2\n'])
 
     def test_status_nonexistent_file(self):
         # files that don't exist in either the basis tree or working tree
@@ -226,22 +253,36 @@
 
     def test_status(self):
         self.run_bzr("init")
+
         self.build_tree(['hello.txt'])
         result = self.run_bzr("status")[0]
         self.assert_("unknown:\n  hello.txt\n" in result, result)
+        result = self.run_bzr("status","--short")[0]
+        self.assert_("?  hello.txt\n" in result, result)
+
         self.run_bzr("add", "hello.txt")
         result = self.run_bzr("status")[0]
         self.assert_("added:\n  hello.txt\n" in result, result)
+        result = self.run_bzr("status","--short")[0]
+        self.assert_("A  hello.txt\n" in result, result)
+
         self.run_bzr("commit", "-m", "added")
         result = self.run_bzr("status", "-r", "0..1")[0]
         self.assert_("added:\n  hello.txt\n" in result, result)
+        result = self.run_bzr("status", "--short", "-r", "0..1")[0]
+        self.assert_("A  hello.txt\n" in result, result)
+
         self.build_tree(['world.txt'])
         result = self.run_bzr("status", "-r", "0")[0]
         self.assert_("added:\n  hello.txt\n" \
                      "unknown:\n  world.txt\n" in result, result)
-
         result2 = self.run_bzr("status", "-r", "0..")[0]
         self.assertEquals(result2, result)
+        result = self.run_bzr("status", "--short", "-r", "0")[0]
+        self.assert_("A  hello.txt\n" \
+                     "?  world.txt\n" in result, result)
+        result2 = self.run_bzr("status", "--short", "-r", "0..")[0]
+        self.assertEquals(result2, result)
 
 
 class TestStatusEncodings(TestCaseWithTransport):

